diff --git a/core/includes/path.inc b/core/includes/path.inc
index 6043749..e4674f5 100644
--- a/core/includes/path.inc
+++ b/core/includes/path.inc
@@ -82,18 +82,7 @@ function drupal_match_path($path, $patterns) {
  * @see request_path()
  */
 function current_path() {
-  // @todo Remove the check for whether the request service exists and the
-  // fallback code below, once the path alias logic has been figured out in
-  // http://drupal.org/node/1269742.
-  if (\Drupal::getContainer()->isScopeActive('request')) {
-    $path = \Drupal::request()->attributes->get('_system_path');
-    if ($path !== NULL) {
-      return $path;
-    }
-  }
-  // If we are outside the request scope, fall back to using the path stored in
-  // _current_path().
-  return _current_path();
+  return \Drupal::request()->attributes->get('_system_path');
 }
 
 /**
diff --git a/core/modules/system/lib/Drupal/system/Tests/Theme/ThemeTest.php b/core/modules/system/lib/Drupal/system/Tests/Theme/ThemeTest.php
index 7d5e16e..3e0d57d 100644
--- a/core/modules/system/lib/Drupal/system/Tests/Theme/ThemeTest.php
+++ b/core/modules/system/lib/Drupal/system/Tests/Theme/ThemeTest.php
@@ -133,14 +133,14 @@ public function testNegotiatorPriorities() {
    * Ensure page-front template suggestion is added when on front page.
    */
   function testFrontPageThemeSuggestion() {
-    $original_path = _current_path();
-    // Set the current path to node because theme_get_suggestions() will query
+    $original_path = \Drupal::request()->attributes->get('_system_path');
+    // Set the system path to node because theme_get_suggestions() will query
     // it to see if we are on the front page.
     \Drupal::config('system.site')->set('page.front', 'node')->save();
-    _current_path('node');
+    \Drupal::request()->attributes->set('_system_path', 'node');
     $suggestions = theme_get_suggestions(array('node'), 'page');
     // Set it back to not annoy the batch runner.
-    _current_path($original_path);
+    \Drupal::request()->attributes->set('_system_path', $original_path);
     $this->assertTrue(in_array('page__front', $suggestions), 'Front page template was suggested.');
   }
 
